ziggy.GraphReduce.gr_path

Package ziggy :: Package GraphReduce :: Module gr_path |
[hide private]
[frames] | no frames]

# Module gr_path

source code

Created on Aug 12, 2010

Author: dwmclary

Functions | [hide private]
connected_components(G, name=None, recompute=False) Compute the connected components for a networkx graph G | source code
num_connected_components(G, name=None, recompute=False) Compute the number of connected components for the networkx graph G. | source code
single_source_shortest_path(G, source, target=None, name=None, recompute=False) Computer the shortest path from source to a target or all other nodes in the networkx graph G. | source code
single_source_shortest_path_length(G, source, target=None, name=None, recompute=False) Computer the shortest path length from source to a target or all other nodes in the networkx graph G. | source code
single_source_average_shortest_path_length(G, source, target=None, name=None, recompute=False) Computer the average shortest path length from source to a target or all other nodes in the networkx graph G. | source code
shortest_path(G, source=None, target=None, name=None, recompute=False) Computer the shortest path from each node to all other nodes in the networkx graph G. | source code
shortest_path_length(G, source=None, target=None, name=None, recompute=False) Computer the shortest path length from each node to all other nodes in the networkx graph G. | source code
average_shortest_path_length(G, name=None, recompute=False) Computer the average shortest path length from each node to all other nodes in the networkx graph G. | source code
average_out_degree(G, name=None) Compute the average out-degree for the networkx graph G. | source code
average_in_degree(G, name=None) Compute the average in-degree for the networkx graph G. | source code
average_degree(G, name=None) Compute the average degree for the networkx graph G. | source code
out_degree(G, name=None) Compute the out-degree for each node in the networkx graph G. | source code
in_degree(G, name=None) Compute the in-degree for each node in the networkx graph G. | source code
degree(G, name=None) Compute the degree for each node in the networkx graph G. | source code
bfs(G, source, name=None) Conduct a parallel BFS from the source node to all other reachable nodes in G. | source code
parallel_degree(hdfs_handle) Compute node degree in parallel for the graph adjacency list stored in hdfs_handle. | source code
parallel_bfs(source, hdfs_handle, old_inf_count) Compute shortest path from source to all nodes in parallel for the graph adjacency list stored in hdfs_handle. | source code
fetch_sp_from_hdfs(hdfs_handle, source) Fetch shortest path results from HDFS. | source code
fetch_degree_from_hdfs(hdfs_handle) Fetch degree results from HDFS. | source code
check_for_precomputed_degree_result(G, name) Check to see if degree has been computed for the networkx graph G. | source code
check_for_precomputed_bfs_result(G, name, source) Check to see if shortest path has been computed for the networkx graph G. | source code

Variables | [hide private]
| __author__ = ``'``D. McClary (dan.mcclary@northwestern.edu)``'``
| __package__ = ``'``ziggy.GraphReduce``'``

Function Details | [hide private]

### shortest_path(G, source=None, target=None, name=None, recompute=False) | source code
Computer the shortest path from each node to all other nodes in the networkx graph G. A source and target can optionally passed to limit the search.

### shortest_path_length(G, source=None, target=None, name=None, recompute=False) | source code
Computer the shortest path length from each node to all other nodes in the networkx graph G. A source and target can optionally passed to limit the search.